#
# spec file for package ghc-hflags
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name hflags
Name:           ghc-%{pkg_name}
Version:        0.4.3
Release:        6.2
Summary:        Command line flag parser, very similar to Google's gflags
License:        Apache-2.0
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-template-haskell-devel
BuildRequires:  ghc-text-devel

%description
The 'HFlags' library supports easy definition of command line flags,
reimplementing the ideas from Google's 'gflags'
(<http://code.google.com/p/gflags>).

Command line flags can be declared in any file at the toplevel, using
'defineFlag'. At runtime, the actual values are assigned to the toplevel
'flags_name' constants. Those can be used purely throughout the program.

At the beginning of the 'main' function, '$initHFlags "program description"'
has to be called to initialize the flags. All flags will be initialized that
are transitively reachable via imports from 'main'. This means, that any
Haskell package can easily define command line flags with 'HFlags'.
This feature is demonstrated by
<http://github.com/errge/hflags/blob/master/examples/ImportExample.hs> and
<http://github.com/errge/hflags/tree/master/examples/package>.

A simple example (more in the
<http://github.com/errge/hflags/tree/master/examples> directory):

' #!%{_bindir}/env runhaskell

&#x7b;-# LANGUAGE TemplateHaskell #-&#x7d;

import HFlags

'defineFlag' "name" "Indiana Jones" "Who to greet." 'defineFlag' "r:repeat" (3
+ 4 :: Int) "Number of times to repeat the message."

main = do s <- $initHFlags "Simple program v0.1" &#x20; sequence_ $ replicate
flags_repeat greet &#x20; putStrLn $ "Your additional arguments were: " ++ show
s &#x20; putStrLn $ "Which is the same as: " ++ show HFlags.arguments &#x20;
where &#x20; greet = putStrLn $ "Hello " ++ flags_name ++ ", very nice to meet
you!" '

At 'initHFlags' time, the library also tries to gather flags out of environment
variables. 'HFLAGS_verbose=True' is equivalent to specify --verbose=True.
This environment feature only works with long options and the user has to
specify a value even for Bools.

/Since version 0.2, you mustn't put the initHFlags in a parentheses with the
program description. Just/ '$initHFlags', /it's cleaner./

See <http://github.com/errge/hflags/tree/master/changelog> for recent changes.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license COPYING

%files devel -f %{name}-devel.files
%doc README.md changelog examples

%changelog
* Thu Apr 12 2018 psimons@suse.com
- Update hflags to version 0.4.3.
  A more detailed change log is not available.
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Tue Jul 19 2016 psimons@suse.com
- Update to version 0.4.2 revision 1 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.4.2 revision 0 with cabal2obs.
